# InlineResponse200

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**environment_configs** | [**list[EnvironmentConfig]**](EnvironmentConfig.md) |  | [optional] 
**limit** | **int** | The maximum number of Environment Configs to return in the response.  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


